#!/bin/sh

init_dev() {

echo "====================================================================="

if [ -d /sys/bus/i2c/drivers/mt9v032/?-00* ]; then
	CAMERA="VM-010(mt9v02x)"
	CAM_DRIVER="mt9v032"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/mt9v032/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/mt9v032/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/mt9p031/?-00* ]; then
	CAMERA="VM-011(mt9p031_mt9p006)"
	CAM_DRIVER="mt9p031"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/mt9p031/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/mt9p031/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/mt9m111/?-00* ]; then
	CAMERA="VM-009(mt9m131)"
	CAM_DRIVER="mt9m111"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/mt9m111/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/mt9m111/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/ar0144/?-00* ]; then
	CAMERA="VM-016(ar0144)"
	CAM_DRIVER="ar0144"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/ar0144/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/ar0144/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
else
	echo "no camera driver loaded"
	echo "please check camera device tree"
	echo ""
	return 1
fi

echo " camera = $CAMERA at i2c bus=$CAM_I2C_BUS with i2c adress=0x$CAM_I2C_ADRESS installed"
echo " camera driver = $CAM_DRIVER"
CAM_ENTITY_NUMBER=`media-ctl -p | grep " $CAM_DRIVER" | awk '{print $3}'`
CAM_DEVICE=$(media-ctl -e "csi capture")
CAM_SUB_DEVICE=$(media-ctl -e "$CAM_DRIVER $CAM_I2C_BUS-00$CAM_I2C_ADRESS")

if [ "$CAM_ENTITY_NUMBER" = "" ]; then
	echo "camera not found"
	echo "please check connected camera type, i2c adress and cable connections"
	echo ""
	return 1
fi
echo " camera entity name = $CAM_ENTITY_NUMBER"
echo " camera device name = $CAM_DEVICE"
echo " camera subdevice name = $CAM_SUB_DEVICE"
echo ""

return 0
}


guess_param() {
	FRAME_SIZE=",width=752,height=480"
	REG_SET_FILE="register-settings-mt9v02x.txt"
	COL_FORMAT="bayer,format=grbg"
	COL_FORMAT_XV="yuv"
#	COL_FORMAT_SCALE="yuv"
	BAYER_CONVERT="bayer2rgbneon ! "
	RAW_COL_FORMAT="bayer"
	NUMBER_OF_PIC="3"
	NORM=""
	if [ $CAMERA = "VM-010(mt9v02x)" ]; then
		FRAME_SIZE=",width=752,height=480"
		FRAME_SIZE_LIVE_DEMO=",width=752,height=480"
		SENSOR_RES="752x480"
		SENSOR_RES_LIVE_DEMO="752x480"
		GRAB_RES="752x480"
		OFFSET_SENSOR="1,5"
		REG_SET_FILE="$(dirname $0)/register-settings-mt9v02x.txt"
		CAM_BW_FMT="Y8"
		COL_FORMAT="bayer,format=grbg" && BAYER_CONVERT="bayer2rgbneon ! "
		CAM_COL_FMT="SGRBG8_1X8"
		RAW_COL_FORMAT="bayer,format=grbg" && COL_FORMAT_XV=$COL_FORMAT
#		COL_FORMAT_SCALE="rgb"
		V4L2_CTRL_CAM0='v4l2-ctl -d '$CAM_SUB_DEVICE' -c row_noise_correction=1'
	elif [ $CAMERA = "VM-011(mt9p031_mt9p006)" ]; then
		FRAME_SIZE=",width=2592,height=1944"
		FRAME_SIZE_LIVE_DEMO=",width=640,height=480"
		SENSOR_RES="2592x1944"
		SENSOR_RES_LIVE_DEMO="2560x1920"
		GRAB_RES="640x480"
		OFFSET_SENSOR="16,54"		
		REG_SET_FILE="$(dirname $0)/register-settings-mt9p031.txt"
		CAM_BW_FMT="Y8"
		COL_FORMAT="bayer,format=grbg" && BAYER_CONVERT="bayer2rgbneon ! "
		CAM_COL_FMT="SGRBG8_1X8"
		RAW_COL_FORMAT="bayer,format=grbg" && COL_FORMAT_XV=$COL_FORMAT
#		COL_FORMAT_SCALE="rgb"
		V4L2_CTRL_CAM0='v4l2-ctl -d '$CAM_SUB_DEVICE' -c exposure=480,gain=32'
	elif [ $CAMERA = "VM-009(mt9m131)" ]; then
		FRAME_SIZE=",width=1280,height=1024"
		FRAME_SIZE_LIVE_DEMO=",width=1280,height=1024"
		SENSOR_RES="1280x1024"
		SENSOR_RES_LIVE_DEMO="1280x1024"		
		GRAB_RES="1280x1024"
		OFFSET_SENSOR="26,8"		
		REG_SET_FILE="$(dirname $0)/register-settings-mt9m131.txt"
		COL_FORMAT="raw,format=YUY2"
		CAM_COL_FMT="YUYV8_2X8"
		BAYER_CONVERT=""
		V4L2_CTRL_CAM0='v4l2-ctl -d '$CAM_SUB_DEVICE' -c auto_exposure=0'
	elif [ $CAMERA = "VM-016(ar0144)" ]; then
		FRAME_SIZE=",width=1280,height=800"
		FRAME_SIZE_LIVE_DEMO=",width=1280,height=800"
		SENSOR_RES="1280x800"
		SENSOR_RES_LIVE_DEMO="1280x800"
		GRAB_RES="1280x800"
		OFFSET_SENSOR="0,4"
		REG_SET_FILE="$(dirname $0)/register-settings-ar0144.txt"
		CAM_BW_FMT="Y8"
		COL_FORMAT="bayer,format=grbg" && BAYER_CONVERT="bayer2rgbneon ! "
		CAM_COL_FMT="SGRBG8_1X8"
		RAW_COL_FORMAT="bayer,format=grbg" && COL_FORMAT_XV=$COL_FORMAT
		NUMBER_OF_PIC="5"
		V4L2_CTRL_CAM0='v4l2-ctl -d '$CAM_SUB_DEVICE' -c auto_exposure_max=720'
	else
		echo "No Camera found"
	fi
}
